@@ -5,12 +5,13 @@ use warnings;
 package Log::Any::Proxy::WithStackTrace;
 
 # ABSTRACT: Log::Any proxy to upgrade string errors to objects with stack traces
-our $VERSION = '1.715';
+our $VERSION = '1.716';
 
 use Log::Any::Proxy;
 our @ISA = qw/Log::Any::Proxy/;
 
 use Devel::StackTrace 2.00;
+use Devel::StackTrace::Extract qw(extract_stack_trace);
 use Log::Any::Adapter::Util ();
 use overload;
 
@@ -18,6 +19,9 @@ use overload;
 #pod
 #pod   use Log::Any qw( $log, proxy_class => 'WithStackTrace' );
 #pod
+#pod   # Turns on argument logging in stack traces
+#pod   use Log::Any qw( $log, proxy_class => 'WithStackTrace', proxy_show_stack_trace_args => 1 );
+#pod
 #pod   # Some adapter that knows how to handle both structured data,
 #pod   # and log messages which are actually objects with a
 #pod   # "stack_trace" method:
@@ -40,7 +44,8 @@ use overload;
 #pod C<Log::Any::MessageWithStackTrace> object with a C<stack_trace> method,
 #pod and that method will return a trace relative to where the logging method
 #pod was called.  A string overload is provided on the object to return the
-#pod original message.
+#pod original message. Unless a C<proxy_show_stack_trace_args> flag is specified, arguments
+#pod in the stack trace will be scrubbed.
 #pod
 #pod B<Important:> This proxy should be used with a L<Log::Any::Adapter> that
 #pod is configured to handle structured data.  Otherwise the object created
@@ -59,13 +64,14 @@ use overload;
 
     sub new
     {
-        my ($class, $message) = @_;
+        my ($class, $proxy_show_stack_trace_args, $message) = @_;
         croak 'no "message"' unless defined $message;
         return bless {
             message     => $message,
             stack_trace => Devel::StackTrace->new(
                 # Filter e.g "Log::Any::Proxy", "My::Log::Any::Proxy", etc.
                 ignore_package => [ qr/(?:^|::)Log::Any(?:::|$)/ ],
+                no_args => !$proxy_show_stack_trace_args,
             ),
         }, $class;
     }
@@ -82,7 +88,8 @@ use overload;
 #pod This is an internal use method that will convert a non-reference scalar
 #pod message into a C<Log::Any::MessageWithStackTrace> object with a
 #pod C<stack_trace> method.  A string overload is provided to return the
-#pod original message.
+#pod original message. Args are scrubbed out in case they contain sensitive data,
+#pod unless the C<proxy_show_stack_trace_args> option has been set.
 #pod
 #pod =cut
 
@@ -93,11 +100,21 @@ sub maybe_upgrade_with_stack_trace
     # Only want a non-ref arg, optionally followed by a structured data
     # context hashref:
     #
+    unless ($self->{proxy_show_stack_trace_args}) {
+        for my $i (0 .. $#args) { # Check if there's a stack trace to scrub args from
+            my $trace = extract_stack_trace($args[$i]);
+            if ($trace) {
+                $self->delete_args_from_stack_trace($trace);
+                $args[$i] = $trace;
+            }
+        }
+    }
+
     return @args unless   @args == 1 ||
                         ( @args == 2 && ref $args[1] eq 'HASH' );
     return @args if ref $args[0];
 
-    $args[0] = Log::Any::MessageWithStackTrace->new($args[0]);
+    $args[0] = Log::Any::MessageWithStackTrace->new($self->{proxy_show_stack_trace_args}, $args[0]);
 
     return @args;
 }
@@ -118,6 +135,26 @@ foreach my $name ( Log::Any::Adapter::Util::logging_methods(), keys(%aliases) )
     };
 }
 
+#pod =head2 delete_args_from_stack_trace($trace)
+#pod
+#pod     $self->delete_args_from_stack_trace($trace)
+#pod
+#pod To scrub potentially sensitive data from C<Devel::StackTrace> arguments, this method deletes
+#pod arguments from all of the C<Devel::StackTrace::Frame> in the trace.
+#pod
+#pod =cut
+
+sub delete_args_from_stack_trace
+{
+    my ($self, $trace) = @_;
+
+    return unless $trace;
+
+    foreach my $frame ($trace->frames) {
+        $frame->{args} = [];
+    }
+}
+
 1;
 
 __END__
@@ -132,12 +169,15 @@ Log::Any::Proxy::WithStackTrace - Log::Any proxy to upgrade string errors to obj
 
 =head1 VERSION
 
-version 1.715
+version 1.716
 
 =head1 SYNOPSIS
 
   use Log::Any qw( $log, proxy_class => 'WithStackTrace' );
 
+  # Turns on argument logging in stack traces
+  use Log::Any qw( $log, proxy_class => 'WithStackTrace', proxy_show_stack_trace_args => 1 );
+
   # Some adapter that knows how to handle both structured data,
   # and log messages which are actually objects with a
   # "stack_trace" method:
@@ -160,7 +200,8 @@ that is a non-reference scalar, that message will be upgraded into a
 C<Log::Any::MessageWithStackTrace> object with a C<stack_trace> method,
 and that method will return a trace relative to where the logging method
 was called.  A string overload is provided on the object to return the
-original message.
+original message. Unless a C<proxy_show_stack_trace_args> flag is specified, arguments
+in the stack trace will be scrubbed.
 
 B<Important:> This proxy should be used with a L<Log::Any::Adapter> that
 is configured to handle structured data.  Otherwise the object created
@@ -174,7 +215,15 @@ trace.
 This is an internal use method that will convert a non-reference scalar
 message into a C<Log::Any::MessageWithStackTrace> object with a
 C<stack_trace> method.  A string overload is provided to return the
-original message.
+original message. Args are scrubbed out in case they contain sensitive data,
+unless the C<proxy_show_stack_trace_args> option has been set.
+
+=head2 delete_args_from_stack_trace($trace)
+
+    $self->delete_args_from_stack_trace($trace)
+
+To scrub potentially sensitive data from C<Devel::StackTrace> arguments, this method deletes
+arguments from all of the C<Devel::StackTrace::Frame> in the trace.
 
 =head1 AUTHORS
 
